@@ -314,13 +314,13 @@ impl ClientApplication {
         }
     }
 
-    pub fn update<'a>(
-        &'a mut self,
+    pub fn update(
+        &mut self,
         resize: Option<(usize, usize)>,
         keys: &[Key],
         stdin_bytes: Option<&[u8]>,
         server_bytes: &[u8],
-    ) -> (bool, &'a [u8]) {
+    ) -> (bool, &'_ [u8]) {
         use io::Write;
 
         self.server_write_buf.clear();
