@@ -7,7 +7,7 @@ use crate::{
     command::{CommandError, CommandIO, CommandManager, CompletionSource},
     config::{ParseConfigError, CONFIG_NAMES},
     cursor::Cursor,
-    editor::{EditorContext, EditorControlFlow},
+    editor::{EditorContext, EditorFlow},
     editor_utils::MessageKind,
     help,
     mode::{picker, read_line, ModeKind},
@@ -80,31 +80,38 @@ pub fn register_commands(commands: &mut CommandManager) {
         if ctx.clients.iter().count() == 1 {
             io.assert_can_discard_all_buffers(ctx)?;
         }
-        io.flow = EditorControlFlow::Quit;
+        io.flow = EditorFlow::Quit;
         Ok(())
     });
 
     r("quit-all", &[], |ctx, io| {
         io.args.assert_empty()?;
         io.assert_can_discard_all_buffers(ctx)?;
-        io.flow = EditorControlFlow::QuitAll;
+        io.flow = EditorFlow::QuitAll;
         Ok(())
     });
 
     r("open", &[CompletionSource::Files], |ctx, io| {
         let path = io.args.next()?;
-        let mode = io.args.try_next().unwrap_or("");
-        io.args.assert_empty()?;
+
+        let mut properties = BufferProperties::text();
+        while let Some(property) = io.args.try_next() {
+            match property {
+                "text" => properties = BufferProperties::text(),
+                "scratch" => properties = BufferProperties::scratch(),
+                "history-enabled" => properties.history_enabled = true,
+                "history-disabled" => properties.history_enabled = false,
+                "saving-enabled" => properties.saving_enabled = true,
+                "saving-disabled" => properties.saving_enabled = false,
+                "word-database-enabled" => properties.word_database_enabled = true,
+                "word-database-disabled" => properties.word_database_enabled = false,
+                _ => return Err(CommandError::NoSuchBufferProperty),
+            }
+        }
 
         let client_handle = io.client_handle()?;
         let (path, position) = parse_path_and_position(path);
 
-        let properties = match mode {
-            "" | "text" => BufferProperties::text(),
-            "scratch" => BufferProperties::scratch(),
-            _ => return Err(CommandError::InvalidBufferMode),
-        };
-
         let path = Path::new(&path);
         match ctx.editor.buffer_view_handle_from_path(
             client_handle,
@@ -158,7 +165,7 @@ pub fn register_commands(commands: &mut CommandManager) {
 
         let mut count = 0;
         for buffer in ctx.editor.buffers.iter_mut() {
-            if buffer.properties.can_save {
+            if buffer.properties.saving_enabled {
                 buffer
                     .write_to_file(None, &mut ctx.editor.events)
                     .map_err(CommandError::BufferWriteError)?;
